diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/08b126ad-32a6-4f39-9233-377eba9be4af.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/08b126ad-32a6-4f39-9233-377eba9be4af.vsidx
new file mode 100644
index 0000000..7d3bd9c
Binary files /dev/null and b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/08b126ad-32a6-4f39-9233-377eba9be4af.vsidx differ
diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/3f4887f2-b0c0-4214-b89e-bf57834ca3fa.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/3f4887f2-b0c0-4214-b89e-bf57834ca3fa.vsidx
new file mode 100644
index 0000000..d213fbe
Binary files /dev/null and b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/3f4887f2-b0c0-4214-b89e-bf57834ca3fa.vsidx differ
diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/81f8a4cc-443d-4b39-b6c8-2943f970f140.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/81f8a4cc-443d-4b39-b6c8-2943f970f140.vsidx
deleted file mode 100644
index 7252987..0000000
Binary files a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/81f8a4cc-443d-4b39-b6c8-2943f970f140.vsidx and /dev/null differ
diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/8240c200-756a-457c-b0d7-7f694fb27f5c.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/8240c200-756a-457c-b0d7-7f694fb27f5c.vsidx
new file mode 100644
index 0000000..375f08f
Binary files /dev/null and b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/8240c200-756a-457c-b0d7-7f694fb27f5c.vsidx differ
diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/9aa516d0-7e2b-4bc3-91cc-2c36f11825d9.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/9aa516d0-7e2b-4bc3-91cc-2c36f11825d9.vsidx
deleted file mode 100644
index 4a1b847..0000000
Binary files a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/9aa516d0-7e2b-4bc3-91cc-2c36f11825d9.vsidx and /dev/null differ
diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/a642fc4b-0ce0-4fa3-84e3-433422cd3e80.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/a642fc4b-0ce0-4fa3-84e3-433422cd3e80.vsidx
deleted file mode 100644
index 9e10c10..0000000
Binary files a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/a642fc4b-0ce0-4fa3-84e3-433422cd3e80.vsidx and /dev/null differ
diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/c1c84aab-0aea-4a9e-8c2e-4e6af279354a.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/c1c84aab-0aea-4a9e-8c2e-4e6af279354a.vsidx
deleted file mode 100644
index 44545ea..0000000
Binary files a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/c1c84aab-0aea-4a9e-8c2e-4e6af279354a.vsidx and /dev/null differ
diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/c680c868-922c-48ef-9295-9e91b641e075.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/c680c868-922c-48ef-9295-9e91b641e075.vsidx
new file mode 100644
index 0000000..35dd316
Binary files /dev/null and b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/c680c868-922c-48ef-9295-9e91b641e075.vsidx differ
diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/e21f8772-6092-4a2c-ae2a-7b81150d9d41.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/e21f8772-6092-4a2c-ae2a-7b81150d9d41.vsidx
new file mode 100644
index 0000000..6f1af9c
Binary files /dev/null and b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/e21f8772-6092-4a2c-ae2a-7b81150d9d41.vsidx differ
diff --git a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/f65e7e4a-afc7-4dec-a79c-c64879c7f921.vsidx b/.vs/TabControlsWithDataGridViews.git/FileContentIndex/f65e7e4a-afc7-4dec-a79c-c64879c7f921.vsidx
deleted file mode 100644
index ae94a5c..0000000
Binary files a/.vs/TabControlsWithDataGridViews.git/FileContentIndex/f65e7e4a-afc7-4dec-a79c-c64879c7f921.vsidx and /dev/null differ
diff --git a/.vs/TabControlsWithDataGridViews.git/v17/.suo b/.vs/TabControlsWithDataGridViews.git/v17/.suo
index 3e12e04..abb04c3 100644
Binary files a/.vs/TabControlsWithDataGridViews.git/v17/.suo and b/.vs/TabControlsWithDataGridViews.git/v17/.suo differ
diff --git a/.vs/TabControlsWithDataGridViews.git/v17/DocumentLayout.json b/.vs/TabControlsWithDataGridViews.git/v17/DocumentLayout.json
index 3c93dc1..a1f8c46 100644
--- a/.vs/TabControlsWithDataGridViews.git/v17/DocumentLayout.json
+++ b/.vs/TabControlsWithDataGridViews.git/v17/DocumentLayout.json
@@ -3,24 +3,24 @@
"WorkspaceRootPath": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\",
"Documents": [
{
- "AbsoluteMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\tabcontrolswithdatagridviews\\tabcontrolswithdatagridviews.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
- "RelativeMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|solutionrelative:tabcontrolswithdatagridviews\\tabcontrolswithdatagridviews.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}"
- },
- {
- "AbsoluteMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\tabcontrolswithdatagridviews\\tabcontrolswithdatagridviews.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}|Form",
- "RelativeMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|solutionrelative:tabcontrolswithdatagridviews\\tabcontrolswithdatagridviews.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}|Form"
- },
- {
- "AbsoluteMoniker": "D:0:0:{47DB0405-1331-455C-ACAE-A2C2FF02B162}|HE-Test_Dll\\HE-Test_Dll.csproj|c:\\cad\\git-workrepository\\visualstudio\\_user control\\tabcontrolswithdatagridviews.git\\he-test_dll\\form1.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}|Form",
- "RelativeMoniker": "D:0:0:{47DB0405-1331-455C-ACAE-A2C2FF02B162}|HE-Test_Dll\\HE-Test_Dll.csproj|solutionrelative:he-test_dll\\form1.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}|Form"
+ "AbsoluteMoniker": "D:0:0:{47DB0405-1331-455C-ACAE-A2C2FF02B162}|HE-Test_Dll\\HE-Test_Dll.csproj|C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\he-test_dll\\form1.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
+ "RelativeMoniker": "D:0:0:{47DB0405-1331-455C-ACAE-A2C2FF02B162}|HE-Test_Dll\\HE-Test_Dll.csproj|solutionrelative:he-test_dll\\form1.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}"
},
{
"AbsoluteMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\tabcontrolswithdatagridviews\\tabcontrolwithdatagridview.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
"RelativeMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|solutionrelative:tabcontrolswithdatagridviews\\tabcontrolwithdatagridview.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}"
},
{
- "AbsoluteMoniker": "D:0:0:{47DB0405-1331-455C-ACAE-A2C2FF02B162}|HE-Test_Dll\\HE-Test_Dll.csproj|C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\he-test_dll\\form1.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
- "RelativeMoniker": "D:0:0:{47DB0405-1331-455C-ACAE-A2C2FF02B162}|HE-Test_Dll\\HE-Test_Dll.csproj|solutionrelative:he-test_dll\\form1.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}"
+ "AbsoluteMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\tabcontrolswithdatagridviews\\tabcontrolswithdatagridviews.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}",
+ "RelativeMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|solutionrelative:tabcontrolswithdatagridviews\\tabcontrolswithdatagridviews.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}"
+ },
+ {
+ "AbsoluteMoniker": "D:0:0:{47DB0405-1331-455C-ACAE-A2C2FF02B162}|HE-Test_Dll\\HE-Test_Dll.csproj|C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\he-test_dll\\form1.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}|Form",
+ "RelativeMoniker": "D:0:0:{47DB0405-1331-455C-ACAE-A2C2FF02B162}|HE-Test_Dll\\HE-Test_Dll.csproj|solutionrelative:he-test_dll\\form1.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}|Form"
+ },
+ {
+ "AbsoluteMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\tabcontrolswithdatagridviews\\tabcontrolswithdatagridviews.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}|Form",
+ "RelativeMoniker": "D:0:0:{A4B2147B-532C-474C-BFBA-D4AB7E6E820E}|TabControlsWithDataGridViews\\TabControlsWithDataGridViews.csproj|solutionrelative:tabcontrolswithdatagridviews\\tabcontrolswithdatagridviews.cs||{A6C744A8-0E4A-4FC6-886A-064283054674}|Form"
}
],
"DocumentGroupContainers": [
@@ -30,7 +30,7 @@
"DocumentGroups": [
{
"DockedHeight": 200,
- "SelectedChildIndex": 6,
+ "SelectedChildIndex": 4,
"Children": [
{
"$type": "Bookmark",
@@ -50,13 +50,13 @@
},
{
"$type": "Document",
- "DocumentIndex": 4,
+ "DocumentIndex": 0,
"Title": "Form1.cs",
"DocumentMoniker": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\HE-Test_Dll\\Form1.cs",
"RelativeDocumentMoniker": "HE-Test_Dll\\Form1.cs",
"ToolTip": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\HE-Test_Dll\\Form1.cs",
"RelativeToolTip": "HE-Test_Dll\\Form1.cs",
- "ViewState": "AQIAAAYAAAAAAAAAAAAAAGgAAABcAAAA",
+ "ViewState": "AQIAAAAAAAAAAAAAAAAAAGgAAABcAAAA",
"Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
"WhenOpened": "2024-05-06T10:49:04.025Z",
"EditorCaption": ""
@@ -64,52 +64,48 @@
{
"$type": "Document",
"DocumentIndex": 2,
+ "Title": "TabControlsWithDataGridViews.cs",
+ "DocumentMoniker": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
+ "RelativeDocumentMoniker": "TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
+ "ToolTip": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
+ "RelativeToolTip": "TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
+ "ViewState": "AQIAAAUAAAAAAAAAAAAowGkAAABSAAAA",
+ "Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
+ "WhenOpened": "2024-05-03T09:00:19.318Z"
+ },
+ {
+ "$type": "Document",
+ "DocumentIndex": 1,
+ "Title": "TabControlWithDataGridView.cs",
+ "DocumentMoniker": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlWithDataGridView.cs",
+ "RelativeDocumentMoniker": "TabControlsWithDataGridViews\\TabControlWithDataGridView.cs",
+ "ToolTip": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlWithDataGridView.cs",
+ "RelativeToolTip": "TabControlsWithDataGridViews\\TabControlWithDataGridView.cs",
+ "ViewState": "AQIAAC8AAAAAAAAAAAAAAFIBAAAIAAAA",
+ "Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
+ "WhenOpened": "2024-05-06T11:52:35.939Z"
+ },
+ {
+ "$type": "Document",
+ "DocumentIndex": 3,
"Title": "Form1.cs [Entwurf]",
"DocumentMoniker": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\HE-Test_Dll\\Form1.cs",
"RelativeDocumentMoniker": "HE-Test_Dll\\Form1.cs",
"ToolTip": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\HE-Test_Dll\\Form1.cs [Entwurf]",
"RelativeToolTip": "HE-Test_Dll\\Form1.cs [Entwurf]",
"Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
- "WhenOpened": "2024-05-06T10:09:33.322Z",
- "EditorCaption": " [Entwurf]"
+ "WhenOpened": "2024-05-06T10:09:33.322Z"
},
{
"$type": "Document",
- "DocumentIndex": 0,
- "Title": "TabControlsWithDataGridViews.cs",
- "DocumentMoniker": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
- "RelativeDocumentMoniker": "TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
- "ToolTip": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
- "RelativeToolTip": "TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
- "ViewState": "AQIAAG0AAAAAAAAAAAAowIkAAABeAAAA",
- "Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
- "WhenOpened": "2024-05-03T09:00:19.318Z",
- "EditorCaption": ""
- },
- {
- "$type": "Document",
- "DocumentIndex": 1,
+ "DocumentIndex": 4,
"Title": "TabControlsWithDataGridViews.cs [Entwurf]",
"DocumentMoniker": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
"RelativeDocumentMoniker": "TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs",
"ToolTip": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs [Entwurf]",
"RelativeToolTip": "TabControlsWithDataGridViews\\TabControlsWithDataGridViews.cs [Entwurf]",
"Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
- "WhenOpened": "2024-05-03T09:00:14.305Z",
- "EditorCaption": " [Entwurf]"
- },
- {
- "$type": "Document",
- "DocumentIndex": 3,
- "Title": "TabControlWithDataGridView.cs",
- "DocumentMoniker": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlWithDataGridView.cs",
- "RelativeDocumentMoniker": "TabControlsWithDataGridViews\\TabControlWithDataGridView.cs",
- "ToolTip": "C:\\CAD\\Git-WorkRepository\\VisualStudio\\_USER CONTROL\\TabControlsWithDataGridViews.git\\TabControlsWithDataGridViews\\TabControlWithDataGridView.cs",
- "RelativeToolTip": "TabControlsWithDataGridViews\\TabControlWithDataGridView.cs",
- "ViewState": "AQIAAAAAAAAAAAAAAAAAAK8BAABUAAAA",
- "Icon": "ae27a6b0-e345-4288-96df-5eaf394ee369.000738|",
- "WhenOpened": "2024-05-06T11:52:35.939Z",
- "EditorCaption": ""
+ "WhenOpened": "2024-05-03T09:00:14.305Z"
}
]
}
diff --git a/HE-Test_Dll/Form1.Designer.cs b/HE-Test_Dll/Form1.Designer.cs
index 552c85a..f58e276 100644
--- a/HE-Test_Dll/Form1.Designer.cs
+++ b/HE-Test_Dll/Form1.Designer.cs
@@ -110,7 +110,6 @@
private System.Windows.Forms.GroupBox groupBoxDLLInfo;
private System.Windows.Forms.Label labelDLLInfo;
private Eugen.ESystem.Windows.Forms.TabControlsWithDataGridViews tabControlsWithDataGridViews;
- private Eugen.ESystem.Windows.Forms.TabControlsWithDataGridViews tabControlsWithDataGridViews1;
}
}
diff --git a/HE-Test_Dll/bin/Debug/HE-Test_Dll.exe b/HE-Test_Dll/bin/Debug/HE-Test_Dll.exe
index 5773414..c493f73 100644
Binary files a/HE-Test_Dll/bin/Debug/HE-Test_Dll.exe and b/HE-Test_Dll/bin/Debug/HE-Test_Dll.exe differ
diff --git a/HE-Test_Dll/bin/Debug/HE-Test_Dll.pdb b/HE-Test_Dll/bin/Debug/HE-Test_Dll.pdb
index 3a1bb3d..f7b1619 100644
Binary files a/HE-Test_Dll/bin/Debug/HE-Test_Dll.pdb and b/HE-Test_Dll/bin/Debug/HE-Test_Dll.pdb differ
diff --git a/HE-Test_Dll/bin/Debug/hetcwdgv.dll b/HE-Test_Dll/bin/Debug/hetcwdgv.dll
index 7c7963c..f390fba 100644
Binary files a/HE-Test_Dll/bin/Debug/hetcwdgv.dll and b/HE-Test_Dll/bin/Debug/hetcwdgv.dll differ
diff --git a/HE-Test_Dll/bin/Debug/hetcwdgv.pdb b/HE-Test_Dll/bin/Debug/hetcwdgv.pdb
index 6601e5d..7713231 100644
Binary files a/HE-Test_Dll/bin/Debug/hetcwdgv.pdb and b/HE-Test_Dll/bin/Debug/hetcwdgv.pdb differ
diff --git a/HE-Test_Dll/obj/Debug/DesignTimeResolveAssemblyReferences.cache b/HE-Test_Dll/obj/Debug/DesignTimeResolveAssemblyReferences.cache
index c06c4c0..a143aa5 100644
Binary files a/HE-Test_Dll/obj/Debug/DesignTimeResolveAssemblyReferences.cache and b/HE-Test_Dll/obj/Debug/DesignTimeResolveAssemblyReferences.cache differ
diff --git a/HE-Test_Dll/obj/Debug/HE-Test_Dll.csproj.AssemblyReference.cache b/HE-Test_Dll/obj/Debug/HE-Test_Dll.csproj.AssemblyReference.cache
index a0219b4..6d725fd 100644
Binary files a/HE-Test_Dll/obj/Debug/HE-Test_Dll.csproj.AssemblyReference.cache and b/HE-Test_Dll/obj/Debug/HE-Test_Dll.csproj.AssemblyReference.cache differ
diff --git a/HE-Test_Dll/obj/Debug/HE-Test_Dll.exe b/HE-Test_Dll/obj/Debug/HE-Test_Dll.exe
index 5773414..c493f73 100644
Binary files a/HE-Test_Dll/obj/Debug/HE-Test_Dll.exe and b/HE-Test_Dll/obj/Debug/HE-Test_Dll.exe differ
diff --git a/HE-Test_Dll/obj/Debug/HE-Test_Dll.pdb b/HE-Test_Dll/obj/Debug/HE-Test_Dll.pdb
index 3a1bb3d..f7b1619 100644
Binary files a/HE-Test_Dll/obj/Debug/HE-Test_Dll.pdb and b/HE-Test_Dll/obj/Debug/HE-Test_Dll.pdb differ
diff --git a/TabControlsWithDataGridViews/Properties/AppResources.Designer.cs b/TabControlsWithDataGridViews/Properties/AppResources.Designer.cs
index 6fd7537..c61e0c3 100644
--- a/TabControlsWithDataGridViews/Properties/AppResources.Designer.cs
+++ b/TabControlsWithDataGridViews/Properties/AppResources.Designer.cs
@@ -59,5 +59,32 @@ namespace Eugen.ESystem.Windows.Forms.Properties {
resourceCulture = value;
}
}
+
+ ///
+ /// Sucht eine lokalisierte Zeichenfolge, die Deletion not possible! ähnelt.
+ ///
+ internal static string Message01 {
+ get {
+ return ResourceManager.GetString("Message01", resourceCulture);
+ }
+ }
+
+ ///
+ /// Sucht eine lokalisierte Zeichenfolge, die Tab cannot be deleted, ähnelt.
+ ///
+ internal static string Message02 {
+ get {
+ return ResourceManager.GetString("Message02", resourceCulture);
+ }
+ }
+
+ ///
+ /// Sucht eine lokalisierte Zeichenfolge, die because the table still contains data! ähnelt.
+ ///
+ internal static string Message03 {
+ get {
+ return ResourceManager.GetString("Message03", resourceCulture);
+ }
+ }
}
}
diff --git a/TabControlsWithDataGridViews/Properties/AppResources.resx b/TabControlsWithDataGridViews/Properties/AppResources.resx
index 4fdb1b6..9cf95ce 100644
--- a/TabControlsWithDataGridViews/Properties/AppResources.resx
+++ b/TabControlsWithDataGridViews/Properties/AppResources.resx
@@ -1,101 +1,129 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- text/microsoft-resx
-
-
- 1.3
-
-
- System.Resources.ResXResourceReader, System.Windows.Forms, Version=2.0.3500.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
-
- System.Resources.ResXResourceWriter, System.Windows.Forms, Version=2.0.3500.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
+ mimetype: application/x-microsoft.net.object.bytearray.base64
+ value : The object must be serialized into a byte array
+ : using a System.ComponentModel.TypeConverter
+ : and then encoded with base64 encoding.
+ -->
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ text/microsoft-resx
+
+
+ 2.0
+
+
+ System.Resources.ResXResourceReader, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ Deletion not possible!
+
+
+ Tab cannot be deleted,
+
+
+ because the table still contains data!
+
\ No newline at end of file
diff --git a/TabControlsWithDataGridViews/Properties/AppResources_de.Designer.cs b/TabControlsWithDataGridViews/Properties/AppResources_de.Designer.cs
index 83db83b..20b9c15 100644
--- a/TabControlsWithDataGridViews/Properties/AppResources_de.Designer.cs
+++ b/TabControlsWithDataGridViews/Properties/AppResources_de.Designer.cs
@@ -59,5 +59,32 @@ namespace Eugen.ESystem.Windows.Forms.Properties {
resourceCulture = value;
}
}
+
+ ///
+ /// Sucht eine lokalisierte Zeichenfolge, die Löschen nicht möglich! ähnelt.
+ ///
+ internal static string Message01 {
+ get {
+ return ResourceManager.GetString("Message01", resourceCulture);
+ }
+ }
+
+ ///
+ /// Sucht eine lokalisierte Zeichenfolge, die Tab kann nicht gelöscht werden, ähnelt.
+ ///
+ internal static string Message02 {
+ get {
+ return ResourceManager.GetString("Message02", resourceCulture);
+ }
+ }
+
+ ///
+ /// Sucht eine lokalisierte Zeichenfolge, die weil die Tabelle noch Daten enthälten! ähnelt.
+ ///
+ internal static string Message03 {
+ get {
+ return ResourceManager.GetString("Message03", resourceCulture);
+ }
+ }
}
}
diff --git a/TabControlsWithDataGridViews/Properties/AppResources_de.resx b/TabControlsWithDataGridViews/Properties/AppResources_de.resx
index 4fdb1b6..9cd34e5 100644
--- a/TabControlsWithDataGridViews/Properties/AppResources_de.resx
+++ b/TabControlsWithDataGridViews/Properties/AppResources_de.resx
@@ -1,101 +1,129 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- text/microsoft-resx
-
-
- 1.3
-
-
- System.Resources.ResXResourceReader, System.Windows.Forms, Version=2.0.3500.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
-
- System.Resources.ResXResourceWriter, System.Windows.Forms, Version=2.0.3500.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
+ mimetype: application/x-microsoft.net.object.bytearray.base64
+ value : The object must be serialized into a byte array
+ : using a System.ComponentModel.TypeConverter
+ : and then encoded with base64 encoding.
+ -->
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ text/microsoft-resx
+
+
+ 2.0
+
+
+ System.Resources.ResXResourceReader, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ Löschen nicht möglich!
+
+
+ Tab kann nicht gelöscht werden,
+
+
+ weil die Tabelle noch Daten enthälten!
+
\ No newline at end of file
diff --git a/TabControlsWithDataGridViews/Properties/AppResources_en.Designer.cs b/TabControlsWithDataGridViews/Properties/AppResources_en.Designer.cs
index a3ec3e6..bd2c3fb 100644
--- a/TabControlsWithDataGridViews/Properties/AppResources_en.Designer.cs
+++ b/TabControlsWithDataGridViews/Properties/AppResources_en.Designer.cs
@@ -59,5 +59,32 @@ namespace Eugen.ESystem.Windows.Forms.Properties {
resourceCulture = value;
}
}
+
+ ///
+ /// Sucht eine lokalisierte Zeichenfolge, die Deletion not possible! ähnelt.
+ ///
+ internal static string Message01 {
+ get {
+ return ResourceManager.GetString("Message01", resourceCulture);
+ }
+ }
+
+ ///
+ /// Sucht eine lokalisierte Zeichenfolge, die Tab cannot be deleted, ähnelt.
+ ///
+ internal static string Message02 {
+ get {
+ return ResourceManager.GetString("Message02", resourceCulture);
+ }
+ }
+
+ ///
+ /// Sucht eine lokalisierte Zeichenfolge, die because the table still contains data! ähnelt.
+ ///
+ internal static string Message03 {
+ get {
+ return ResourceManager.GetString("Message03", resourceCulture);
+ }
+ }
}
}
diff --git a/TabControlsWithDataGridViews/Properties/AppResources_en.resx b/TabControlsWithDataGridViews/Properties/AppResources_en.resx
index 4fdb1b6..9cf95ce 100644
--- a/TabControlsWithDataGridViews/Properties/AppResources_en.resx
+++ b/TabControlsWithDataGridViews/Properties/AppResources_en.resx
@@ -1,101 +1,129 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- text/microsoft-resx
-
-
- 1.3
-
-
- System.Resources.ResXResourceReader, System.Windows.Forms, Version=2.0.3500.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
-
- System.Resources.ResXResourceWriter, System.Windows.Forms, Version=2.0.3500.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
+ mimetype: application/x-microsoft.net.object.bytearray.base64
+ value : The object must be serialized into a byte array
+ : using a System.ComponentModel.TypeConverter
+ : and then encoded with base64 encoding.
+ -->
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ text/microsoft-resx
+
+
+ 2.0
+
+
+ System.Resources.ResXResourceReader, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ Deletion not possible!
+
+
+ Tab cannot be deleted,
+
+
+ because the table still contains data!
+
\ No newline at end of file
diff --git a/TabControlsWithDataGridViews/Properties/AssemblyInfo.cs b/TabControlsWithDataGridViews/Properties/AssemblyInfo.cs
index 22fccd6..166a78b 100644
--- a/TabControlsWithDataGridViews/Properties/AssemblyInfo.cs
+++ b/TabControlsWithDataGridViews/Properties/AssemblyInfo.cs
@@ -31,5 +31,5 @@ using System.Runtime.InteropServices;
// Sie können alle Werte angeben oder Standardwerte für die Build- und Revisionsnummern verwenden,
// indem Sie "*" wie unten gezeigt eingeben:
// [assembly: AssemblyVersion("1.0.*")]
-[assembly: AssemblyVersion("1.0.0.0")]
-[assembly: AssemblyFileVersion("1.0.0.0")]
+[assembly: AssemblyVersion("1.0.*")]
+//[assembly: AssemblyFileVersion("1.0.0.0")]
diff --git a/TabControlsWithDataGridViews/TabControlsWithDataGridViews.cs b/TabControlsWithDataGridViews/TabControlsWithDataGridViews.cs
index 4d2f85e..3e43444 100644
--- a/TabControlsWithDataGridViews/TabControlsWithDataGridViews.cs
+++ b/TabControlsWithDataGridViews/TabControlsWithDataGridViews.cs
@@ -106,52 +106,16 @@ namespace Eugen.ESystem.Windows.Forms
private void TabControlsWithDataGridViews_Load(object sender, EventArgs e)
{
// Correct TabControlSize
- if (TabControlWidth < minWidth)
- {
- this.Width = minWidth;
- TabControlWidth = this.Width - 80;
- }
- else if (TabControlWidth > maxWidth)
- {
- this.Width = maxWidth;
- TabControlWidth = this.Width - 80;
- }
-
- if (TabControlHeight < minHeight)
- {
- this.Height = minHeight;
- TabControlHeight = this.Height - 26;
- }
- else if (TabControlHeight > maxHeight)
- {
- this.Height = minHeight;
- TabControlHeight = this.Height - 26;
- }
+ CorrectTabControlSize();
// Set the max. number of tabs
tcwdgv.MaxNoOfTabs = maxNoOfTabs;
// Set the control button location
- int controlButtonDistance = (panelButton.Width - (controlButtonWidth * 5) - 6) / 4 + controlButtonWidth; // X distance from the origin point of one button to the origin point of the next button
- buttonRemoveTab.Location = new System.Drawing.Point(controlButtonXDistance + controlButtonDistance, 3);
- buttonRemoveSelectedTab.Location = new System.Drawing.Point(controlButtonXDistance + 2 * controlButtonDistance, 3);
- buttonMoveTabToLeft.Location = new System.Drawing.Point(controlButtonXDistance + 2 + 3 * controlButtonDistance, 3);
+ SetControlButtonLocation();
- tcwdgv.TabControlWidth = TabControlWidth; // The 'TabControl' width
- tcwdgv.TabControlHeight = TabControlHeight; // The 'TabControl' hight
- tcwdgv.TabTitle = TabTitle; // The title of a 'tabPage'
- tcwdgv.Column1Title = Column1Title; // The title of column 1
- tcwdgv.Column2Title = Column2Title; // The title of column 2
- tcwdgv.MoveToButtonTitle = MoveToButtonTitle; // The title of the 'Move to' buttons
- tcwdgv.CreatingTabControl(Controls); // Create a 'TabControl' and a 'TabPage' with a 'DataGridView'
-
- if (String.IsNullOrEmpty(DataPath))
- {
- DataPath = "";
- }
- tcwdgv.DataPath = DataPath;
-
- tcwdgv.Extension = Extension;
+ // Set DataPath and Extension
+ SetDataPathAndExtension();
// Reads all files from the root directory and writes them to the tables
tcwdgv.CreatesATabForEachDirectory(); // Creates a tab for each directory in the root directory
@@ -203,6 +167,61 @@ namespace Eugen.ESystem.Windows.Forms
///
public static string MoveToButtonTitle { set; get; }
+ private void CorrectTabControlSize()
+ {
+ // Correct TabControlSize
+ if (TabControlWidth < minWidth)
+ {
+ this.Width = minWidth;
+ TabControlWidth = this.Width - 80;
+ }
+ else if (TabControlWidth > maxWidth)
+ {
+ this.Width = maxWidth;
+ TabControlWidth = this.Width - 80;
+ }
+
+ if (TabControlHeight < minHeight)
+ {
+ this.Height = minHeight;
+ TabControlHeight = this.Height - 26;
+ }
+ else if (TabControlHeight > maxHeight)
+ {
+ this.Height = minHeight;
+ TabControlHeight = this.Height - 26;
+ }
+ }
+
+ private void SetControlButtonLocation()
+ {
+ // Set the control button location
+ int controlButtonDistance = (panelButton.Width - (controlButtonWidth * 5) - 6) / 4 + controlButtonWidth; // X distance from the origin point of one button to the origin point of the next button
+ buttonRemoveTab.Location = new System.Drawing.Point(controlButtonXDistance + controlButtonDistance, 3);
+ buttonRemoveSelectedTab.Location = new System.Drawing.Point(controlButtonXDistance + 2 * controlButtonDistance, 3);
+ buttonMoveTabToLeft.Location = new System.Drawing.Point(controlButtonXDistance + 2 + 3 * controlButtonDistance, 3);
+
+ tcwdgv.TabControlWidth = TabControlWidth; // The 'TabControl' width
+ tcwdgv.TabControlHeight = TabControlHeight; // The 'TabControl' hight
+ tcwdgv.TabTitle = TabTitle; // The title of a 'tabPage'
+ tcwdgv.Column1Title = Column1Title; // The title of column 1
+ tcwdgv.Column2Title = Column2Title; // The title of column 2
+ tcwdgv.MoveToButtonTitle = MoveToButtonTitle; // The title of the 'Move to' buttons
+ tcwdgv.CreatingTabControl(Controls); // Create a 'TabControl' and a 'TabPage' with a 'DataGridView'
+ }
+
+ private void SetDataPathAndExtension()
+ {
+ // Set DataPath and Extension
+ if (String.IsNullOrEmpty(DataPath))
+ {
+ DataPath = "";
+ }
+ tcwdgv.DataPath = DataPath;
+
+ tcwdgv.Extension = Extension;
+ }
+
private void buttonAddTab_Click(object sender, EventArgs e)
{
tcwdgv.AddTabPageWithDataGridViewAndButton(); // Add an additional 'TabPage' with a 'DataGridView'
diff --git a/TabControlsWithDataGridViews/TabControlsWithDataGridViews.csproj b/TabControlsWithDataGridViews/TabControlsWithDataGridViews.csproj
index c64278c..928626a 100644
--- a/TabControlsWithDataGridViews/TabControlsWithDataGridViews.csproj
+++ b/TabControlsWithDataGridViews/TabControlsWithDataGridViews.csproj
@@ -10,7 +10,7 @@
hetcwdgv
v4.7.2
512
- true
+ false
true
diff --git a/TabControlsWithDataGridViews/bin/Debug/hetcwdgv.dll b/TabControlsWithDataGridViews/bin/Debug/hetcwdgv.dll
index 7c7963c..f390fba 100644
Binary files a/TabControlsWithDataGridViews/bin/Debug/hetcwdgv.dll and b/TabControlsWithDataGridViews/bin/Debug/hetcwdgv.dll differ
diff --git a/TabControlsWithDataGridViews/bin/Debug/hetcwdgv.pdb b/TabControlsWithDataGridViews/bin/Debug/hetcwdgv.pdb
index 6601e5d..7713231 100644
Binary files a/TabControlsWithDataGridViews/bin/Debug/hetcwdgv.pdb and b/TabControlsWithDataGridViews/bin/Debug/hetcwdgv.pdb differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/DesignTimeResolveAssemblyReferences.cache b/TabControlsWithDataGridViews/obj/Debug/DesignTimeResolveAssemblyReferences.cache
index 2d21f8d..c5634ba 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/DesignTimeResolveAssemblyReferences.cache and b/TabControlsWithDataGridViews/obj/Debug/DesignTimeResolveAssemblyReferences.cache differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources.resources b/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources.resources
index 6c05a97..ff04fad 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources.resources and b/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources.resources differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources_de.resources b/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources_de.resources
index 6c05a97..18f52a3 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources_de.resources and b/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources_de.resources differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources_en.resources b/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources_en.resources
index 6c05a97..ff04fad 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources_en.resources and b/TabControlsWithDataGridViews/obj/Debug/Eugen.ESystem.Windows.Forms.Properties.AppResources_en.resources differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/TabControlsWithDataGridViews.csproj.CoreCompileInputs.cache b/TabControlsWithDataGridViews/obj/Debug/TabControlsWithDataGridViews.csproj.CoreCompileInputs.cache
index 6a8c07a..8ed588b 100644
--- a/TabControlsWithDataGridViews/obj/Debug/TabControlsWithDataGridViews.csproj.CoreCompileInputs.cache
+++ b/TabControlsWithDataGridViews/obj/Debug/TabControlsWithDataGridViews.csproj.CoreCompileInputs.cache
@@ -1 +1 @@
-362805a9dc970ac2fcfe5e123d4c993f907ae6939b9faf3dc1a0f00343231b22
+25dea20c05cdab1f8de104339a71dea088d604726eceef75f37ee555dee20a6f
diff --git a/TabControlsWithDataGridViews/TabControlWithDataGridView.cs b/TabControlsWithDataGridViews/TabControlWithDataGridView.cs
index 8906674..4b97033 100644
--- a/TabControlsWithDataGridViews/TabControlWithDataGridView.cs
+++ b/TabControlsWithDataGridViews/TabControlWithDataGridView.cs
@@ -4,6 +4,7 @@ using System.Drawing;
using System.IO;
using System.Linq;
using System.Windows.Forms;
+using AppRes = Eugen.ESystem.Windows.Forms.Properties.AppResources;
namespace Eugen.ESystem.Windows.Forms
{
@@ -89,8 +90,6 @@ namespace Eugen.ESystem.Windows.Forms
private int SelectedRow { get; set; }
private List> AllFiles { get; set; }
- int maxNumbersOfTabPages = 12;
-
#region Public Methodes
///
/// Creates a tab for each directory in the root directory
@@ -107,27 +106,11 @@ namespace Eugen.ESystem.Windows.Forms
{
List> fileList = ReadFromDirectory(Extension); // Read files from directory
- // Only file with the defined extension are allowed
- foreach (var item in fileList)
- {
- for (int i = 0; i < item.Count; i++)
- {
- if (Path.GetExtension(item[i].GetValue(1).ToString()) != Extension)
- {
- fileList.Remove(item);
- }
- }
- }
+ CorrectFileList(fileList); // Only file with the defined extension are allowed
DataGridView dataGridView = DynamicTabControl.SelectedTab.Controls.OfType().FirstOrDefault(); // Chang the control to the first dataGridView
- for (int i = 0; i < DynamicTabControl.TabCount; i++)
- {
- DynamicTabControl.SelectedIndex = i; //Set the selected 'TabPage' as current 'TabPage'
- dataGridView = DynamicTabControl.SelectedTab.Controls.OfType().FirstOrDefault(); // Chang the control to the current dataGridView
-
- WriteDataGridView(dataGridView, fileList[i]);
- }
+ SetCurrentTabPageAndFillWithData(dataGridView, fileList); // Set the selected 'TabPage' as current 'TabPage' and fill with data
// Actavate the first 'TabPage'
DynamicTabControl.SelectedIndex = setTab; //Set the selected 'TabPage' as current 'TabPage'
@@ -209,7 +192,7 @@ namespace Eugen.ESystem.Windows.Forms
{
int numberOfTabs = DynamicTabControl.TabCount;
- if (numberOfTabs < maxNumbersOfTabPages)
+ if (numberOfTabs < MaxNoOfTabs)
{
AddMoveToButton(Controls, numberOfTabs); // Add Button to UserControl
AddTabPage(DynamicTabControl, numberOfTabs); // Add TabPage to TabControl
@@ -258,7 +241,7 @@ namespace Eugen.ESystem.Windows.Forms
}
else
{
- MessageBox.Show("Löschen nicht möglich!\n\r\n\rTab kann nicht gelöscht werden,\n\rweil die Tabelle noch Daten enthälten!\n\r");
+ MessageBox.Show(AppRes.Message01 + "\n\r\n\r" + AppRes.Message02 + "\n\r" + AppRes.Message03 + "\n\r");
}
}
}
@@ -300,7 +283,7 @@ namespace Eugen.ESystem.Windows.Forms
}
else
{
- MessageBox.Show("Löschen nicht möglich!\n\r\n\rTab kann nicht gelöscht werden,\n\rweil die Tabelle noch Daten enthälten!\n\r");
+ MessageBox.Show(AppRes.Message01 + "\n\r\n\r" + AppRes.Message02 + "\n\r" + AppRes.Message03 + "\n\r");
}
RenameTabs(DynamicTabControl); // Rename all 'TabControl' so that they are numbered consecutively again
@@ -356,9 +339,15 @@ namespace Eugen.ESystem.Windows.Forms
#region Private Methodes
private List> ReadFromDirectory(string extension)
{
- // Read all directories from the root directory
- string[] directories = Directory.GetDirectories(DataPath);
+ string[] directories = Directory.GetDirectories(DataPath); // Read all directories from the root directory
+ AllFiles = CreatesAListOfAllFilesInAllDirectories(directories); // Creates a list of all files in all directories
+
+ return AllFiles;
+ }
+
+ private List> CreatesAListOfAllFilesInAllDirectories(string[] directories)
+ {
// Creates a list of all files in all directories
List> allFiles = new List>();
@@ -384,11 +373,37 @@ namespace Eugen.ESystem.Windows.Forms
allFiles.Add(filesInTable); // Adds all files of a directory to the list
}
- AllFiles = allFiles;
-
return allFiles;
}
+ private List> CorrectFileList(List> fileList)
+ {
+ // Only file with the defined extension are allowed
+ foreach (var item in fileList)
+ {
+ for (int i = 0; i < item.Count; i++)
+ {
+ if (Path.GetExtension(item[i].GetValue(1).ToString()) != Extension)
+ {
+ fileList.Remove(item);
+ }
+ }
+ }
+
+ return fileList;
+ }
+
+ private void SetCurrentTabPageAndFillWithData(DataGridView dataGridView, List> fileList)
+ {
+ for (int i = 0; i < DynamicTabControl.TabCount; i++)
+ {
+ DynamicTabControl.SelectedIndex = i; //Set the selected 'TabPage' as current 'TabPage'
+ dataGridView = DynamicTabControl.SelectedTab.Controls.OfType().FirstOrDefault(); // Chang the control to the current dataGridView
+
+ WriteDataGridView(dataGridView, fileList[i]);
+ }
+ }
+
private void AddTabPage(TabControl dynamicTabControl, int count)
{
TabPage tabPage = new TabPage();
@@ -433,7 +448,7 @@ namespace Eugen.ESystem.Windows.Forms
{
Button moveToButton = new Button();
- if (number < maxNumbersOfTabPages)
+ if (number < MaxNoOfTabs)
{
moveToButton.Name = "buttonMoveTo" + number.ToString();
moveToButton.Location = new System.Drawing.Point(TabControlWidth + 80 - 78 - 25, 10 + 58 + (number + 1) * 29 - 29);
diff --git a/TabControlsWithDataGridViews/obj/Debug/TabControlsWithDataGridViews.csproj.GenerateResource.cache b/TabControlsWithDataGridViews/obj/Debug/TabControlsWithDataGridViews.csproj.GenerateResource.cache
index 18ab0b8..1473310 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/TabControlsWithDataGridViews.csproj.GenerateResource.cache and b/TabControlsWithDataGridViews/obj/Debug/TabControlsWithDataGridViews.csproj.GenerateResource.cache differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources.Designer.cs.dll b/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources.Designer.cs.dll
index 4fd7a25..1d0515a 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources.Designer.cs.dll and b/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources.Designer.cs.dll differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources_de.Designer.cs.dll b/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources_de.Designer.cs.dll
index fe119b1..738b5b4 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources_de.Designer.cs.dll and b/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources_de.Designer.cs.dll differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources_en.Designer.cs.dll b/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources_en.Designer.cs.dll
index a637fe2..d419582 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources_en.Designer.cs.dll and b/TabControlsWithDataGridViews/obj/Debug/TempPE/Properties.AppResources_en.Designer.cs.dll differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/hetcwdgv.dll b/TabControlsWithDataGridViews/obj/Debug/hetcwdgv.dll
index 7c7963c..f390fba 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/hetcwdgv.dll and b/TabControlsWithDataGridViews/obj/Debug/hetcwdgv.dll differ
diff --git a/TabControlsWithDataGridViews/obj/Debug/hetcwdgv.pdb b/TabControlsWithDataGridViews/obj/Debug/hetcwdgv.pdb
index 6601e5d..7713231 100644
Binary files a/TabControlsWithDataGridViews/obj/Debug/hetcwdgv.pdb and b/TabControlsWithDataGridViews/obj/Debug/hetcwdgv.pdb differ